@@ -24,6 +24,7 @@ COMMAND_MODULES = (
     'ocdskit.cli.commands.schema_report',
     'ocdskit.cli.commands.schema_strict',
     'ocdskit.cli.commands.set_closed_codelist_enums',
+    'ocdskit.cli.commands.split_project_packages',
     'ocdskit.cli.commands.split_record_packages',
     'ocdskit.cli.commands.split_release_packages',
     'ocdskit.cli.commands.tabulate',
@@ -66,7 +67,7 @@ def main():
                     if isinstance(e.args[0], bytes):  # YAJL backends
                         message = e.args[0].decode(errors='backslashreplace')
                     _raise_encoding_error(message, args.encoding)
-                raise CommandError('JSON error: {}'.format(e))
+                raise CommandError('JSON error: {}'.format(e)) from e
             except UnicodeDecodeError as e:
                 _raise_encoding_error(e, args.encoding)
         except CommandError as e:
