@@ -6,8 +6,10 @@ from ocdsmerge.util import get_release_schema_url, get_tags
 
 from ocdskit.exceptions import MissingRecordsWarning, MissingReleasesWarning
 from ocdskit.packager import Packager
-from ocdskit.util import (_default_version, _empty_record_package, _empty_release_package,
-                          _remove_empty_optional_metadata, _resolve_metadata, _update_package_metadata)
+from ocdskit.util import (_empty_record_package, _empty_release_package, _remove_empty_optional_metadata,
+                          _resolve_metadata, _update_package_metadata)
+
+DEFAULT_VERSION = '1.1'  # fields might be deprecated
 
 
 def _package(key, items, uri, publisher, published_date, version, extensions=None):
@@ -30,7 +32,7 @@ def _package(key, items, uri, publisher, published_date, version, extensions=Non
     return output
 
 
-def package_records(records, uri='', publisher=None, published_date='', version=_default_version, extensions=None):
+def package_records(records, uri='', publisher=None, published_date='', version=DEFAULT_VERSION, extensions=None):
     """
     Wraps records in a record package.
 
@@ -44,7 +46,7 @@ def package_records(records, uri='', publisher=None, published_date='', version=
     return _package('records', records, uri, publisher, published_date, version, extensions)
 
 
-def package_releases(releases, uri='', publisher=None, published_date='', version=_default_version, extensions=None):
+def package_releases(releases, uri='', publisher=None, published_date='', version=DEFAULT_VERSION, extensions=None):
     """
     Wraps releases in a release package.
 
@@ -58,7 +60,7 @@ def package_releases(releases, uri='', publisher=None, published_date='', versio
     return _package('releases', releases, uri, publisher, published_date, version, extensions)
 
 
-def combine_record_packages(packages, uri='', publisher=None, published_date='', version=_default_version):
+def combine_record_packages(packages, uri='', publisher=None, published_date='', version=DEFAULT_VERSION):
     """
     Collects the packages and records from the record packages into one record package.
 
@@ -93,7 +95,7 @@ def combine_record_packages(packages, uri='', publisher=None, published_date='',
     return output
 
 
-def combine_release_packages(packages, uri='', publisher=None, published_date='', version=_default_version):
+def combine_release_packages(packages, uri='', publisher=None, published_date='', version=DEFAULT_VERSION):
     """
     Collects the releases from the release packages into one release package.
 
@@ -124,7 +126,7 @@ def combine_release_packages(packages, uri='', publisher=None, published_date=''
     return output
 
 
-def merge(data, uri='', publisher=None, published_date='', version=_default_version, schema=None,
+def merge(data, uri='', publisher=None, published_date='', version=DEFAULT_VERSION, schema=None,
           return_versioned_release=False, return_package=False, use_linked_releases=False, streaming=False):
     """
     Merges release packages and individual releases.
@@ -150,7 +152,7 @@ def merge(data, uri='', publisher=None, published_date='', version=_default_vers
     :param bool streaming: if ``return_package`` is ``True``, set the package's records to a generator (this only works
         if the calling code exhausts the generator before ``merge`` returns)
     :raises InconsistentVersionError: if the versions are inconsistent across packages to merge
-    :raises MissingOcidKeyError: if the release is missing an ``ocid`` key
+    :raises MissingOcidKeyError: if the release is missing an ``ocid`` field
     """
     with Packager() as packager:
         packager.add(data)
