@@ -1,5 +1,6 @@
 import itertools
 import os
+from abc import ABC, abstractmethod
 from collections import defaultdict
 from tempfile import NamedTemporaryFile
 
@@ -9,18 +10,19 @@ from ocdskit.util import (_empty_record_package, _remove_empty_optional_metadata
 
 try:
     import sqlite3
-    using_sqlite = True
 
-    def adapt_json(d):
-        return json_dumps(d)
+    USING_SQLITE = True
 
-    def convert_json(s):
-        return jsonlib.loads(s)
+    def adapt_json(data):
+        return json_dumps(data)
+
+    def convert_json(string):
+        return jsonlib.loads(string)
 
     sqlite3.register_adapter(dict, adapt_json)
     sqlite3.register_converter('json', convert_json)
 except ImportError:
-    using_sqlite = False
+    USING_SQLITE = False
 
 
 class Packager:
@@ -29,18 +31,19 @@ class Packager:
     releases. Release packages and/or individual releases can be added to the packager. All releases should use the
     same version of OCDS.
     """
-    def __enter__(self):
+    def __init__(self):
         self.package = _empty_record_package()
         self.version = None
 
-        if using_sqlite:
+        if USING_SQLITE:
             self.backend = SQLiteBackend()
         else:
             self.backend = PythonBackend()
 
+    def __enter__(self):
         return self
 
-    def __exit__(self, type, value, traceback):
+    def __exit__(self, type_, value, traceback):
         self.backend.close()
 
     def add(self, data):
@@ -144,7 +147,7 @@ class Packager:
         :param ocdsmerge.merge.Merger merger: a merger
         :param bool return_versioned_release: whether to yield versioned releases instead of compiled releases
         """
-        for ocid, rows in self.backend.get_releases_by_ocid():
+        for _, rows in self.backend.get_releases_by_ocid():
             releases = (row[-1] for row in rows)
 
             if return_versioned_release:
@@ -159,46 +162,39 @@ class Packager:
 # * Store each release's package URI
 #
 # For a PostgreSQL backend, see https://github.com/open-contracting/ocdskit/issues/116
-class AbstractBackend:
-    def __init__(self):
-        """
-        Initializes the backend.
-        """
-        raise NotImplementedError
-
+class AbstractBackend(ABC):
     def add_release(self, release, package_uri):
         """
         Adds a release to the backend. (The release might be added to an internal buffer.)
 
-        :raises MissingOcidKeyError: if the release is missing an ``ocid`` key
+        :raises MissingOcidKeyError: if the release is missing an ``ocid`` field
         """
         try:
             self._add_release(release['ocid'], package_uri, release)
-        except KeyError:
-            raise MissingOcidKeyError('ocid')
+        except KeyError as e:
+            raise MissingOcidKeyError('ocid') from e
 
+    @abstractmethod
     def _add_release(self, ocid, package_uri, release):
-        raise NotImplementedError
+        pass
 
+    @abstractmethod
     def get_releases_by_ocid(self):
         """
         Yields an OCIDs and an iterable of tuples of ``(ocid, package_uri, release)``.
 
         OCIDs are yielded in alphabetical order. The iterable is in any order.
         """
-        raise NotImplementedError
 
     def flush(self):
         """
         Flushes the internal buffer of releases. This may be a no-op on some backends.
         """
-        pass
 
     def close(self):
         """
         Tidies up any resources used by the backend. This may be a no-op on some backends.
         """
-        pass
 
 
 class PythonBackend(AbstractBackend):
